@@ -3,16 +3,16 @@
 
 package Device::USB::PX1674;
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 use strict;
 use warnings;
 use Carp;
-use Device::USB;
 
 sub new{
     my $class = shift;
     my %cfg = (
+        devices => [],    # since version 1.03
         vid  => 0xFFFF,   # Vendor ID
         pid  => 0x1122,   # Product ID
         ept  => 0x02,     # Endpoint Out
@@ -37,9 +37,18 @@ sub new{
     eval{
         my $vid = sprintf "%04X", $cfg{vid};
         my $pid = sprintf "%04X", $cfg{pid};
-        my $usb = Device::USB->new();
-        $usb->find_busses || die "No USB busses found!\n";
-        my $dev = $usb->find_device($cfg{vid}, $cfg{pid} ) or die "Device Vendor '$vid', Product '$pid' not found\n";
+        my $usb = $self->{CFG}{usb};
+        
+        #my $dev = $usb->find_device($cfg{vid}, $cfg{pid} ) or die "Device Vendor '$vid', Product '$pid' not found\n";
+        my $dev = undef;
+        foreach my $d( @{$self->{CFG}{devices}} ){
+            if( $d->idVendor == $cfg{vid} && $d->idProduct == $cfg{pid} ){
+                $dev = $d;
+                last;
+            }
+        }
+        die "Device Vendor '$vid', Product '$pid' not found\n"
+            unless $dev;
         $dev->open || die "Error open device!\n";
         
         if( $dev->set_configuration($cfg{cfg}) != 0 ){
@@ -92,8 +101,12 @@ sub AUTOLOAD{
 }
 sub DESTROY{}
 1;#########################################################################
-# my $px = Device::USB::PX1674->new or die $@;
-# $px->Off;
+
+#use Device::USB;
+#my $usb = Device::USB->new;
+#my $px = Device::USB::PX1674->new( devices => [$usb->list_devices] ) or die $@;
+#$px->Off;
+
 __END__
 
 =head1 NAME
@@ -103,11 +116,14 @@ Device::USB::PX1674 - Perl CMD-Class for Revolt USB Dongle PX-1674-675
 
 =head1 SYNOPSIS
 
+  use Device::USB;
   use Device::USB::PX1674;
+  my $usb = Device::USB->new;
   
   my $px = Device::USB::PX1674->new(
-    addr => 0x1A85, # inhouse code
-    verb => 1,      # verbose output, shown as hex-dump
+    devices => [$usb->list_devices],
+    addr    => 0x1A85, # inhouse code
+    verb    => 1,      # verbose output, shown as hex-dump
   ) || die $@;
 
   # Set Device 1 to state on
@@ -136,6 +152,8 @@ Available options are:
   cfg  => 1,        # Default Configuration
   verb => 0,        # Verbose 
 
+  devices => [$usb->list_devices] # new in version 1.03
+
 =head2 METHODS
 
   On();
@@ -149,8 +167,8 @@ Available options are:
 
 =head2 PPM Packages for Win32
 
-ppm install http://rolfrost.de/Device-USB.ppd
-ppm install http://rolfrost.de/Device-USB-PX1674.ppd
+  ppm install http://rolfrost.de/Device-USB.ppd
+  ppm install http://rolfrost.de/Device-USB-PX1674.ppd
 
 =head1 SEE ALSO
 
